==> asset-consumer-api-0.1-sources.jar: org/odpi/openmetadata/accessservices/assetconsumer/rest/AssetConsumerOMASAPIRequestBody.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the Egeria project. */

package org.odpi.openmetadata.accessservices.assetconsumer.rest;

import com.fasterxml.jackson.annotation.*;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * AssetConsumerOMASAPIRequestBody provides a common header for Asset Consumer OMAS request bodies for its REST API.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME,
        include = JsonTypeInfo.As.PROPERTY,
        property = "class")
@JsonSubTypes(
        {
                @JsonSubTypes.Type(value = LogRecordRequestBody.class, name = "LogRecordRequestBody"),
                @JsonSubTypes.Type(value = TagRequestBody.class, name = "TagRequestBody"),
                @JsonSubTypes.Type(value = CommentRequestBody.class, name = "CommentRequestBody"),
                @JsonSubTypes.Type(value = RatingRequestBody.class, name = "RatingRequestBody")
        })
public abstract class AssetConsumerOMASAPIRequestBody implements java.io.Serializable
{
    private static final long    serialVersionUID = 1L;


    /**
     * Default constructor
     */
    public AssetConsumerOMASAPIRequestBody()
    {
    }


    /**
     * Copy/clone constructor
     *
     * @param template object to copy
     */
    public AssetConsumerOMASAPIRequestBody(AssetConsumerOMASAPIRequestBody template)
    {
    }


    /**
     * JSON-like toString
     *
     * @return string containing the class name
     */
    @Override
    public String toString()
    {
        return "AssetConsumerOMASAPIRequestBody{}";
    }
}

==> asset-consumer-api-0.2-sources.jar: org/odpi/openmetadata/accessservices/assetconsumer/rest/AssetConsumerOMASAPIRequestBody.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */

package org.odpi.openmetadata.accessservices.assetconsumer.rest;

import com.fasterxml.jackson.annotation.*;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * AssetConsumerOMASAPIRequestBody provides a common header for Asset Consumer OMAS request bodies for its REST API.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME,
        include = JsonTypeInfo.As.PROPERTY,
        property = "class")
@JsonSubTypes(
        {
                @JsonSubTypes.Type(value = LogRecordRequestBody.class, name = "LogRecordRequestBody"),
                @JsonSubTypes.Type(value = MyProfileRequestBody.class, name = "MyProfileRequestBody"),
                @JsonSubTypes.Type(value = AssetCollectionRequestBody.class, name = "AssetCollectionRequestBody"),
                @JsonSubTypes.Type(value = TagRequestBody.class, name = "TagRequestBody"),
                @JsonSubTypes.Type(value = CommentRequestBody.class, name = "CommentRequestBody"),
                @JsonSubTypes.Type(value = RatingRequestBody.class, name = "RatingRequestBody")
        })
public abstract class AssetConsumerOMASAPIRequestBody implements java.io.Serializable
{
    private static final long    serialVersionUID = 1L;


    /**
     * Default constructor
     */
    public AssetConsumerOMASAPIRequestBody()
    {
    }


    /**
     * Copy/clone constructor
     *
     * @param template object to copy
     */
    public AssetConsumerOMASAPIRequestBody(AssetConsumerOMASAPIRequestBody template)
    {
    }


    /**
     * JSON-like toString
     *
     * @return string containing the class name
     */
    @Override
    public String toString()
    {
        return "AssetConsumerOMASAPIRequestBody{}";
    }
}
